<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Rtform_site extends MX_Controller
{

    public function index()
    {
        $this->load->model('rtform/rtform_tmodel');
        
        $content = [
            'items' => $this->rtform_tmodel->fetch_all(),
        ];

        return $this->parser->parse('rtform/template', $content, TRUE);
    }

}
