<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_rtform_message
{
    private $message = '';

    public function set_message($message)
    {
        $this->message = $message;
        return $this;
    }
    
    public function get_message()
    {
        return $this->message;
    }

    public function parse($prefix = '', $suffix = '')
    {
        return empty($this->message) ? '' : ($prefix . $this->message . $suffix);
    }

}