<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_form_error
{

    public function parse($field = '', $prefix = '', $suffix = '')
    {
        $ci = get_instance();
        $ci->load->helper('form');

        return form_error($field, $prefix, $suffix);
    }

}