<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_form_close
{

    public function parse($extra = '')
    {
        $ci = get_instance();
        $ci->load->helper('form');

        return form_close($extra);
    }

}