<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_form_set_radio
{

    public function parse($field, $value = '', $default = false)
    {
        $ci = get_instance();
        $ci->load->helper('form');

        return set_radio($field, $value, $default);
    }

}